@@ -50,11 +50,13 @@ def handle_delete_functions():
     _, project_to_config = get_master_config()
     for project, config in project_to_config.items():
         function_paths = [functions.get_relative_function_path(p) for p in config]
-        pr_refs = github.get_open_pr_refs()
+        if os.environ["GITLAB_CLIENT"] == "True":
+            pr_refs = github.gitlab_open_mrs(str(os.environ["CI_PROJECT_ID"]), str(os.environ["GITLAB_ACCESS_TOKEN"]))
+        else:
+            pr_refs = github.get_open_pr_refs()
         all_functions = [functions.get_function_name(f, latest=True) for f in function_paths] + [
             functions.get_function_name(f, pr=True, ref=ref) for ref, f in list(product(pr_refs, function_paths))
         ]
-
         info = const.PROJECTS_TO_API_KEYS[project]
         client = cdf.experimental_client(info.project)
         dangling = functions.list_dangling_function(client, all_functions, name_prefix=env.get_repo_name_auto())
